@@ -6,8 +6,9 @@ impl Ident {
         filter::<_, _, Error>(|c: &char| c.is_alphanumeric() || *c == '-' || *c == '_')
             .repeated()
             .at_least(1)
-            .map_with_span(|val, span| Ident {
-                _span: span.into(),
+            .map_with_span(|val, _span| Ident {
+                #[cfg(feature = "spanned")]
+                span: _span.into(),
                 val: String::from_iter(val),
             })
     }
@@ -18,8 +19,9 @@ impl IntLit {
         just::<_, _, Error>('-')
             .or_not()
             .then(filter(|c: &char| c.is_numeric()).repeated().at_least(1))
-            .map_with_span(|(neg, val), span| IntLit {
-                span: span.into(),
+            .map_with_span(|(neg, val), _span| IntLit {
+                #[cfg(feature = "spanned")]
+                span: _span.into(),
                 val: match (String::from_iter(val).parse::<i64>().unwrap(), neg) {
                     (val, Some(_)) => -val,
                     (val, None) => val,
@@ -32,7 +34,8 @@ impl NonZeroIntLit {
     fn parser() -> impl Parser<Input, NonZeroIntLit, Error = Error> {
         IntLit::parser().try_map(|il, span| {
             Ok(NonZeroIntLit {
-                _span: il.span,
+                #[cfg(feature = "spanned")]
+                span: il.span,
                 val: il
                     .val
                     .try_into()
@@ -47,8 +50,9 @@ impl StringContent {
         none_of::<_, _, Error>([delimiter])
             .or(just(format!("\\{}", delimiter)).to(delimiter))
             .repeated()
-            .map_with_span(|content, span| StringContent {
-                _span: span.into(),
+            .map_with_span(|content, _span| StringContent {
+                #[cfg(feature = "spanned")]
+                span: _span.into(),
                 val: String::from_iter(content),
             })
     }
@@ -60,9 +64,9 @@ impl SingleStringLit {
             .then(StringContent::parser('\''))
             .then(token::SingleQuote::parser())
             .map(|((start, content), end)| SingleStringLit {
-                _start: start,
+                start,
                 content,
-                _end: end,
+                end,
             })
     }
 }
@@ -73,9 +77,9 @@ impl DoubleStringLit {
             .then(StringContent::parser('"'))
             .then(token::DoubleQuote::parser())
             .map(|((start, content), end)| DoubleStringLit {
-                _start: start,
+                start,
                 content,
-                _end: end,
+                end,
             })
     }
 }
@@ -93,8 +97,9 @@ impl BoolLit {
         just::<_, _, Error>("true")
             .to(true)
             .or(just("false").to(false))
-            .map_with_span(|val, span| BoolLit {
-                _span: span.into(),
+            .map_with_span(|val, _span| BoolLit {
+                #[cfg(feature = "spanned")]
+                span: _span.into(),
                 val,
             })
     }
@@ -102,19 +107,22 @@ impl BoolLit {
 
 impl NullLit {
     fn parser() -> impl Parser<Input, NullLit, Error = Error> {
-        just::<_, _, Error>("null").map_with_span(|_, span| NullLit { _span: span.into() })
+        just::<_, _, Error>("null").map_with_span(|_, _span| NullLit {
+            #[cfg(feature = "spanned")]
+            span: _span.into(),
+        })
     }
 }
 
 impl Path {
     pub(crate) fn parser() -> impl Parser<Input, Path, Error = Error> {
         token::Dollar::parser()
-            .then(Operator::parser().repeated())
+            .then(Segment::parser().repeated())
             .then(token::Tilde::parser().or_not())
             .then_ignore(end())
-            .map(|((dollar, children), tilde)| Path {
-                _dollar: dollar,
-                children,
+            .map(|((dollar, segments), tilde)| Path {
+                dollar,
+                segments,
                 tilde,
             })
     }
@@ -122,14 +130,14 @@ impl Path {
 
 impl SubPath {
     fn parser(
-        operator: impl Parser<Input, Operator, Error = Error>,
+        operator: impl Parser<Input, Segment, Error = Error>,
     ) -> impl Parser<Input, SubPath, Error = Error> {
         PathKind::parser()
             .then(operator.repeated())
             .then(token::Tilde::parser().or_not())
-            .map(|((kind, children), tilde)| SubPath {
+            .map(|((kind, segments), tilde)| SubPath {
                 kind,
-                children,
+                segments,
                 tilde,
             })
     }
@@ -143,38 +151,38 @@ impl PathKind {
     }
 }
 
-impl Operator {
-    fn parser() -> impl Parser<Input, Operator, Error = Error> {
+impl Segment {
+    fn parser() -> impl Parser<Input, Segment, Error = Error> {
         recursive(|operator| {
             token::DotDot::parser()
                 .then(RecursiveOp::parser(operator.clone()).or_not())
-                .map(|(dotdot, op)| Operator::Recursive(dotdot, op))
-                .or(token::Bracket::parser(BracketInner::parser(operator))
-                    .map(|(brack, inner)| Operator::Bracket(brack, inner)))
+                .map(|(dotdot, op)| Segment::Recursive(dotdot, op))
+                .or(token::Bracket::parser(BracketSelector::parser(operator))
+                    .map(|(brack, inner)| Segment::Bracket(brack, inner)))
                 .or(token::Dot::parser()
-                    .then(DotIdent::parser())
-                    .map(|(dot, ident)| Operator::Dot(dot, ident)))
+                    .then(RawSelector::parser())
+                    .map(|(dot, ident)| Segment::Dot(dot, ident)))
         })
     }
 }
 
 impl RecursiveOp {
     fn parser(
-        operator: impl Parser<Input, Operator, Error = Error> + Clone + 'static,
+        operator: impl Parser<Input, Segment, Error = Error> + Clone + 'static,
     ) -> impl Parser<Input, RecursiveOp, Error = Error> {
-        DotIdent::parser()
+        RawSelector::parser()
             .map(RecursiveOp::Raw)
-            .or(token::Bracket::parser(BracketInner::parser(operator))
+            .or(token::Bracket::parser(BracketSelector::parser(operator))
                 .map(|(bracket, inner)| RecursiveOp::Bracket(bracket, inner)))
     }
 }
 
-impl DotIdent {
-    fn parser() -> impl Parser<Input, DotIdent, Error = Error> {
+impl RawSelector {
+    fn parser() -> impl Parser<Input, RawSelector, Error = Error> {
         token::Star::parser()
-            .map(DotIdent::Wildcard)
-            .or(token::Caret::parser().map(DotIdent::Parent))
-            .or(Ident::parser().map(DotIdent::Name))
+            .map(RawSelector::Wildcard)
+            .or(token::Caret::parser().map(RawSelector::Parent))
+            .or(Ident::parser().map(RawSelector::Name))
     }
 }
 
@@ -188,9 +196,9 @@ impl StepRange {
             .then(NonZeroIntLit::parser().or_not())
             .map(|((((start, colon1), end), colon2), step)| StepRange {
                 start,
-                _colon1: colon1,
+                colon1,
                 end,
-                _colon2: colon2,
+                colon2,
                 step,
             })
     }
@@ -202,17 +210,13 @@ impl Range {
             .or_not()
             .then(token::Colon::parser())
             .then(IntLit::parser().or_not())
-            .map(|((start, colon), end)| Range {
-                start,
-                _colon: colon,
-                end,
-            })
+            .map(|((start, colon), end)| Range { start, colon, end })
     }
 }
 
 impl UnionComponent {
     fn parser(
-        operator: impl Parser<Input, Operator, Error = Error> + Clone + 'static,
+        operator: impl Parser<Input, Segment, Error = Error> + Clone + 'static,
     ) -> impl Parser<Input, UnionComponent, Error = Error> {
         StepRange::parser()
             .map(UnionComponent::StepRange)
@@ -225,21 +229,21 @@ impl UnionComponent {
     }
 }
 
-impl BracketInner {
+impl BracketSelector {
     fn parser(
-        operator: impl Parser<Input, Operator, Error = Error> + Clone + 'static,
-    ) -> impl Parser<Input, BracketInner, Error = Error> {
+        operator: impl Parser<Input, Segment, Error = Error> + Clone + 'static,
+    ) -> impl Parser<Input, BracketSelector, Error = Error> {
         UnionComponent::parser(operator.clone())
             .separated_by(just(','))
             .at_least(2)
-            .map(BracketInner::Union)
-            .or(StepRange::parser().map(BracketInner::StepRange))
-            .or(Range::parser().map(BracketInner::Range))
-            .or(token::Star::parser().map(BracketInner::Wildcard))
-            .or(token::Caret::parser().map(BracketInner::Parent))
-            .or(SubPath::parser(operator.clone()).map(BracketInner::Path))
-            .or(Filter::parser(operator).map(BracketInner::Filter))
-            .or(BracketLit::parser().map(BracketInner::Literal))
+            .map(BracketSelector::Union)
+            .or(StepRange::parser().map(BracketSelector::StepRange))
+            .or(Range::parser().map(BracketSelector::Range))
+            .or(token::Star::parser().map(BracketSelector::Wildcard))
+            .or(token::Caret::parser().map(BracketSelector::Parent))
+            .or(SubPath::parser(operator.clone()).map(BracketSelector::Path))
+            .or(Filter::parser(operator).map(BracketSelector::Filter))
+            .or(BracketLit::parser().map(BracketSelector::Literal))
             .padded()
     }
 }
@@ -254,13 +258,13 @@ impl BracketLit {
 
 impl Filter {
     fn parser(
-        operator: impl Parser<Input, Operator, Error = Error> + Clone + 'static,
+        operator: impl Parser<Input, Segment, Error = Error> + Clone + 'static,
     ) -> impl Parser<Input, Filter, Error = Error> {
         token::Question::parser()
             .then(token::Paren::parser(FilterExpr::parser(operator)))
             .map(|(question, (paren, inner))| Filter {
-                _question: question,
-                _paren: paren,
+                question,
+                paren,
                 inner,
             })
     }
@@ -278,7 +282,7 @@ impl ExprLit {
 
 impl FilterExpr {
     fn parser(
-        operator: impl Parser<Input, Operator, Error = Error> + Clone + 'static,
+        operator: impl Parser<Input, Segment, Error = Error> + Clone + 'static,
     ) -> impl Parser<Input, FilterExpr, Error = Error> {
         recursive(|filt_expr| {
             let atom = SubPath::parser(operator)
@@ -324,20 +328,20 @@ impl UnOp {
 }
 
 impl BinOp {
-    pub fn product_parser() -> impl Parser<Input, BinOp, Error = Error> {
+    fn product_parser() -> impl Parser<Input, BinOp, Error = Error> {
         token::Star::parser()
             .map(BinOp::Mul)
             .or(token::RightSlash::parser().map(BinOp::Div))
             .or(token::Percent::parser().map(BinOp::Rem))
     }
 
-    pub fn sum_parser() -> impl Parser<Input, BinOp, Error = Error> {
+    fn sum_parser() -> impl Parser<Input, BinOp, Error = Error> {
         token::Plus::parser()
             .map(BinOp::Add)
             .or(token::Dash::parser().map(BinOp::Sub))
     }
 
-    pub fn cmp_parser() -> impl Parser<Input, BinOp, Error = Error> {
+    fn cmp_parser() -> impl Parser<Input, BinOp, Error = Error> {
         token::EqEq::parser()
             .map(BinOp::Eq)
             .or(token::LessEq::parser().map(BinOp::Le))
@@ -346,11 +350,11 @@ impl BinOp {
             .or(token::GreaterThan::parser().map(BinOp::Gt))
     }
 
-    pub fn and_parser() -> impl Parser<Input, BinOp, Error = Error> {
+    fn and_parser() -> impl Parser<Input, BinOp, Error = Error> {
         token::DoubleAnd::parser().map(BinOp::And)
     }
 
-    pub fn or_parser() -> impl Parser<Input, BinOp, Error = Error> {
+    fn or_parser() -> impl Parser<Input, BinOp, Error = Error> {
         token::DoublePipe::parser().map(BinOp::Or)
     }
 }
